@@ -12,6 +12,7 @@ DEFAULT_HARDLINKEM=False
 DEFAULT_MINSIZE=2**10
 DEFAULT_MAXSIZE=2**33
 DEFAULT_PROFILES=False
+DEFAULT_INCLUDE_NAMES_IN_PROFILES=False
 
 READSIZE=8192
 
@@ -33,6 +34,7 @@ def main():
     parser.add_argument("-m", "--min-size", help="Ignore files smaller than this (default %d)." % DEFAULT_MINSIZE, default=DEFAULT_MINSIZE, type=int, metavar='m')
     parser.add_argument("-M", "--max-size", help="Hash only the first this many bytes of the file (default %d)." % DEFAULT_MAXSIZE, default=DEFAULT_MAXSIZE, type=int, metavar='M')
     parser.add_argument("-p", "--profiles", help="Print out the md5sum and size in bytes of every file.  This could be useful for a p2p storage project to measure how valuable convergent encryption is.", default=DEFAULT_PROFILES, action='store_true')
+    parser.add_argument("--include-names-in-profiles", help="Print out the file name in addition to the other information from --profiles, for each file.", default=DEFAULT_INCLUDE_NAMES_IN_PROFILES, action='store_true')
     parser.add_argument("-n", "--no-follow-symlinks", help="Do not follow symlinks.", default=DEFAULT_PROFILES, action='store_true')
     parser.add_argument("dir", nargs='*', help="directories to recursively examine (default '.')", default=".")
     args = parser.parse_args()
@@ -45,5 +47,5 @@ def main():
         print "Sorry, hard links don't work on Windows."
         sys.exit(-1)
 
-    return dupfilefind.dffem(len(args.verbose), args.ignore_dirs.split(','), args.hard_link_them, args.delete_them, args.min_size, args.max_size, args.profiles, args.no_follow_symlinks, args.dir, WINDOWS)
+    return dupfilefind.dffem(len(args.verbose), args.ignore_dirs.split(','), args.hard_link_them, args.delete_them, args.min_size, args.max_size, args.profiles, args.include_names_in_profiles, args.no_follow_symlinks, args.dir, WINDOWS)
 
