@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-import bsddb, errno, md5, os, stat, struct, sys
+import anydbm, errno, md5, os, stat, struct, sys
 
 from cPickle import dumps, loads
 
@@ -42,11 +42,11 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILE
 
     tempd = fileutil.NamedTemporaryDirectory()
     db1fname = os.path.join(tempd.name, TMPDB1FNAME)
-    d1 = bsddb.btopen(db1fname, "n")
+    d1 = anydbm.open(db1fname, "n")
     tempd.register_file(d1)
     fileutil.remove_if_possible(db1fname)
     db2fname = os.path.join(tempd.name, TMPDB2FNAME)
-    d2 = bsddb.btopen(db2fname, "n")
+    d2 = anydbm.open(db2fname, "n")
     tempd.register_file(d2)
     fileutil.remove_if_possible(db2fname)
     try:
